==> image_sizes-8.x-1.15.tar.gz: image_sizes/src/Plugin/Field/FieldFormatter/ImageSizesPresetFormatter.php <==
<?php

namespace Drupal\image_sizes\Plugin\Field\FieldFormatter;

use Drupal\image_sizes\ImageSizesFormatterTrait;
use Drupal\image_sizes\Entity\ImageSizesPresetEntity;
use Drupal\image\Entity\ImageStyle;
use Drupal\file\Entity\File;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FieldItemInterface;
use Drupal\Component\Serialization\Json;

/**
 * Plugin implementation of the 'image_sizes_formatter' formatter.
 *
 * @FieldFormatter(
 *   id = "image_sizes_preset_formatter",
 *   label = @Translation("Image sizes presets"),
 *   field_types = {
 *     "image",
 *     "entity_reference"
 *   }
 * )
 */
class ImageSizesPresetFormatter extends FormatterBase {

  use ImageSizesFormatterTrait;

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      // Implement default settings.
      'preset' => FALSE,
      'load_invisible' => false,
    ] + parent::defaultSettings();
  }

  /**
   * Helper function forloading preset.
   */
  private function getPreset() {
    return \Drupal::entityTypeManager()
      ->getStorage('image_sizes_preset_entity')
      ->load($this->getSetting('preset'));
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    return [
      // Implement settings form.
      'load_invisible' => [
        '#type' => 'checkbox',
        '#default_value' => $this->getSetting('load_invisible'),
        '#title' => $this->t('Load this image even is not visible')
      ],
      'preset' => [
        '#type' => 'select',
        '#required' => TRUE,
        '#title' => $this->t('Placeholder image style.'),
        '#options' => $this->getOptions(),
        '#default_value' => $this->getSetting('preset'),
      ],
    ] + parent::settingsForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = [];
    // Implement settings summary.
    $preset = $this->getPreset();
    if ($preset) {
      $summary['#markup'] = $preset->label();
    }

    return $summary;
  }



  /**
   * Get all options for select a style.
   */
  protected function getOptions() {
    $presets = \Drupal::entityQuery('image_sizes_preset_entity')
      ->execute();
    $options = [];
    foreach ($presets as $preset) {
      if ($preset = ImageSizesPresetEntity::load($preset)) {
        $options[$preset->id()] = $preset->label();
      }
    }
    return $options;
  }

  /**
   * Get all uris for selected styles.
   */
  protected function getStyles($uri) {
    $preset = $this->getPreset();
    $image_styles = ImageStyle::loadMultiple($preset->getStyles());
    foreach ($image_styles as $style) {
      $effects = $style->getEffects();
      foreach ($effects as $effect) {
        if (is_a($effect, 'Drupal\image\Plugin\ImageEffect\ResizeImageEffect')) {
          $width = $effect->getConfiguration()['data']['width'];
          if ($width !== NULL && $width > 0) {
            $styles[$width] = $style->buildUrl($uri);
          }
        }
      }
    }
    ksort($styles);
    return $styles;
  }

  /**
   * Get uri for fallback style or original image if no fallback is assigned.
   */
  protected function getFallBackStyle($uri) {
    $preset = $this->getPreset();

    if ($preset->getFallbackStyle() == 'original') {
      return file_create_url($uri);
    }

    $style = ImageStyle::load($preset->getFallbackStyle());
    if (!$style) {
      return file_create_url($uri);
    }

    return $style->buildUrl($uri);
  }

  /**
   * Get uri for preload style or original image if no fallback is assigned.
   */
  protected function getPreloadStyle($uri) {
    $preset = $this->getPreset();

    if ($preset->getPreloadStyle() == 'original') {
      return file_create_url($uri);
    }

    $style = ImageStyle::load($preset->getPreloadStyle());
    if (!$style) {
      return file_create_url($uri);
    }

    return $style->buildUrl($uri);
  }

  /**
   * {@inheritdoc}
   */
  public function calculateDependencies() {
    $dependencies = parent::calculateDependencies();
    $preset = $this->getPreset();

    $dependencies[$preset->getConfigDependencyKey()][] = $preset->getConfigDependencyName();

    return $dependencies;
  }

  /**
   * Generate the output appropriate for one field item.
   *
   * @param \Drupal\Core\Field\FieldItemInterface $item
   *   One field item.
   *
   * @return string
   *   The textual output generated.
   */
  protected function viewValue(FieldItemInterface $item) {
    $item = $this->getField($item);
    $file = File::load($item->target_id);
    if (!$file) {
      return [];
    }
    $preset = $this->getPreset();
    $render = [
      '#theme' => 'image_style',
      '#style_name' => $preset->getPreloadStyle(),
      '#uri' => $file->getFileUri(),
      '#attributes' => [
        'data-src' => Json::encode($this->getStyles($file->getFileUri())),
        'class' => [
          'image-sizes',
          'pre-load',
        ],
        'data-src-fallback' => $this->getFallBackStyle($file->getFileUri()),
      ],
    ];
    if ($this->getSetting('load_invisible')) {
      $render['#attributes']['class'][] = 'load-always';
    }
    if (isset($item->title)) {
      $render['#attributes']['title'] = $item->title;
    }
    if (isset($item->alt)) {
      $render['#attributes']['alt'] = $item->alt;
    }

    return $render;
  }

}

==> image_sizes-8.x-1.16.tar.gz: image_sizes/src/Plugin/Field/FieldFormatter/ImageSizesPresetFormatter.php <==
<?php

namespace Drupal\image_sizes\Plugin\Field\FieldFormatter;

use Drupal\image_sizes\ImageSizesFormatterTrait;
use Drupal\image_sizes\Entity\ImageSizesPresetEntity;
use Drupal\image\Entity\ImageStyle;
use Drupal\file\Entity\File;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FieldItemInterface;
use Drupal\Component\Serialization\Json;

/**
 * Plugin implementation of the 'image_sizes_formatter' formatter.
 *
 * @FieldFormatter(
 *   id = "image_sizes_preset_formatter",
 *   label = @Translation("Image sizes presets"),
 *   field_types = {
 *     "image",
 *     "entity_reference"
 *   }
 * )
 */
class ImageSizesPresetFormatter extends FormatterBase {

  use ImageSizesFormatterTrait;

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      // Implement default settings.
      'preset' => FALSE,
      'load_invisible' => false,
    ] + parent::defaultSettings();
  }

  /**
   * Helper function forloading preset.
   */
  private function getPreset() {
    return \Drupal::entityTypeManager()
      ->getStorage('image_sizes_preset_entity')
      ->load($this->getSetting('preset'));
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    return [
      // Implement settings form.
      'load_invisible' => [
        '#type' => 'checkbox',
        '#default_value' => $this->getSetting('load_invisible'),
        '#title' => $this->t('Load this image even is not visible')
      ],
      'preset' => [
        '#type' => 'select',
        '#required' => TRUE,
        '#title' => $this->t('Placeholder image style.'),
        '#options' => $this->getOptions(),
        '#default_value' => $this->getSetting('preset'),
      ],
    ] + parent::settingsForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = [];
    // Implement settings summary.
    $preset = $this->getPreset();
    if ($preset) {
      $summary['#markup'] = $preset->label();
    }

    return $summary;
  }



  /**
   * Get all options for select a style.
   */
  protected function getOptions() {
    $presets = \Drupal::entityQuery('image_sizes_preset_entity')
      ->execute();
    $options = [];
    foreach ($presets as $preset) {
      if ($preset = ImageSizesPresetEntity::load($preset)) {
        $options[$preset->id()] = $preset->label();
      }
    }
    return $options;
  }

  /**
   * Get all uris for selected styles.
   */
  protected function getStyles($uri) {
    $preset = $this->getPreset();
    $image_styles = ImageStyle::loadMultiple($preset->getStyles());
    foreach ($image_styles as $style) {
      $effects = $style->getEffects();
      foreach ($effects as $effect) {
        if (is_a($effect, 'Drupal\image\Plugin\ImageEffect\ResizeImageEffect')) {
          $width = $effect->getConfiguration()['data']['width'];
          if ($width !== NULL && $width > 0) {
            $styles[$width] = $style->buildUrl($uri);
          }
        }
      }
    }
    ksort($styles);
    return $styles;
  }

  /**
   * Get uri for fallback style or original image if no fallback is assigned.
   */
  protected function getFallBackStyle($uri) {
    $preset = $this->getPreset();

    if ($preset->getFallbackStyle() == 'original') {
      return file_create_url($uri);
    }

    $style = ImageStyle::load($preset->getFallbackStyle());
    if (!$style) {
      return file_create_url($uri);
    }

    return $style->buildUrl($uri);
  }

  /**
   * Get uri for preload style or original image if no fallback is assigned.
   */
  protected function getPreloadStyle($uri) {
    $preset = $this->getPreset();

    if ($preset->getPreloadStyle() == 'original') {
      return file_create_url($uri);
    }

    $style = ImageStyle::load($preset->getPreloadStyle());
    if (!$style) {
      return file_create_url($uri);
    }

    return $style->buildUrl($uri);
  }

  /**
   * {@inheritdoc}
   */
  public function calculateDependencies() {
    $dependencies = parent::calculateDependencies();
    $preset = $this->getPreset();

    $dependencies[$preset->getConfigDependencyKey()][] = $preset->getConfigDependencyName();

    return $dependencies;
  }

  /**
   * Generate the output appropriate for one field item.
   *
   * @param \Drupal\Core\Field\FieldItemInterface $item
   *   One field item.
   *
   * @return string
   *   The textual output generated.
   */
  protected function viewValue(FieldItemInterface $item) {
    $uri = $this->getFileUri($item);
    if (!$uri) {
      return [];
    }
    $preset = $this->getPreset();
    $render = [
      '#theme' => 'image_style',
      '#style_name' => $preset->getPreloadStyle(),
      '#uri' => $uri,
      '#attributes' => [
        'data-src' => Json::encode($this->getStyles($uri)),
        'class' => [
          'image-sizes',
          'pre-load',
        ],
        'data-src-fallback' => $this->getFallBackStyle($uri),
      ],
    ];
    if ($this->getSetting('load_invisible')) {
      $render['#attributes']['class'][] = 'load-always';
    }
    if (isset($item->title)) {
      $render['#attributes']['title'] = $item->title;
    }
    if (isset($item->alt)) {
      $render['#attributes']['alt'] = $item->alt;
    }

    return $render;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];
    foreach ($items as $delta => $item) {
      $elements[$delta] = $this->viewValue($item);
    }
    $elements['#attached']['library'] = ['image_sizes/core'];
    return $elements;
  }

}
